@@ -1,7 +1,8 @@
 testthat::context("test-estimate_pcf_fast")
 
-pcf <- shar::estimate_pcf_fast(pattern = shar::species_b)
-
 testthat::test_that("estimate_pcf returns spatstat.fv object", {
-  testthat::expect_is(pcf, "fv")
+
+  pcf_est <- shar::estimate_pcf_fast(pattern = shar::species_b)
+
+  testthat::expect_is(pcf_est, "fv")
 })
