@@ -69,6 +69,18 @@ testthat::test_that("All optional arguments can be used for reconstruct_marks",
   testthat::expect_length(marks_recon, n = 4)
 })
 
+testthat::test_that("Reconstruction stops if e_threshold is reached", {
+
+  marks_recon <- shar::reconstruct_marks(pattern = pattern_recon,
+                                         marked_pattern = marks_sub,
+                                         e_threshold = 0.5,
+                                         verbose = FALSE)
+
+  # testthat::expect_lt(object = shar::calculate_energy(marks_recon, verbose = FALSE),
+  #                     expected = 0.5)
+})
+
+
 testthat::test_that("All errors are returned for reconstruct_marks", {
 
   testthat::expect_error(shar::reconstruct_marks(pattern = pattern_recon,
@@ -107,20 +119,18 @@ testthat::test_that("All errors are returned for reconstruct_marks", {
                          regexp = "marks must be 'numeric'")
 })
 
-test_that("All warnings are returned for reconstruct_marks", {
+testthat::test_that("All warnings are returned for reconstruct_marks", {
 
-  expect_warning(shar::reconstruct_marks(pattern = pattern_recon,
-                                         marked_pattern = marks_sub,
-                                         n_random = 2, max_runs = 1,
-                                         return_input = FALSE,
-                                         simplify = TRUE,
-                                         verbose = FALSE),
-                 regexp = "'simplify = TRUE' not possible for 'n_random > 1'")
+  testthat::expect_warning(shar::reconstruct_marks(pattern = pattern_recon,
+                                                   marked_pattern = marks_sub,
+                                                   n_random = 2, max_runs = 1,
+                                                   return_input = FALSE,
+                                                   simplify = TRUE),
+                           regexp = "'simplify = TRUE' not possible for 'n_random > 1'")
 
-  expect_warning(shar::reconstruct_marks(pattern = pattern_recon,
-                                         marked_pattern = marks_sub,
-                                         n_random = 1, max_runs = 1,
-                                         simplify = TRUE,
-                                         verbose = FALSE),
-                 regexp = "'simplify = TRUE' not possible for 'return_input = TRUE'")
+  testthat::expect_warning(shar::reconstruct_marks(pattern = pattern_recon,
+                                                   marked_pattern = marks_sub,
+                                                   n_random = 1, max_runs = 1,
+                                                   simplify = TRUE),
+                           regexp = "'simplify = TRUE' not possible for 'return_input = TRUE'")
 })
